#!/bin/bash

ENVS_TO_EXPECT=()
ENV_JSON=$NGINX_HTML_FOLDER/assets/env.json
DEBUG=${DEBUG:-0}

# checks for required environment variables
for env in "${ENVS_TO_EXPECT[@]}" ; do
   if [[ -z $(eval echo $env) ]] ; then
      echo Required environment variable $env not set >&2
      exit 1
   fi
done

# on k8s runtime we use SSL cert & key provided by the associated Secret object.
# on a local development environment (e.g. docker compose) we expect dev certificates
# to be present at the bootstrap script location.
if [[ ! -z $KUBERNETES_SERVICE_HOST ]] ; then
   RUNTIME=k8s
   if [[ -f $NGINX_HOME/conf.d/includes/dev-ssl.conf ]] ; then
      rm $NGINX_HOME/conf.d/includes/dev-ssl.conf
   fi
   # k8s pods can access the internal dns service, and therefore have a solid way
   # to resolve the API server by the hostname.
   sed -e "s/##KUBERNETES_SERVICE_HOST/kube-apiserver-lb-svc.kube-system.svc.cluster.local/g" \
       -e "s/##KUBERNETES_SERVICE_PORT_HTTPS/$KUBERNETES_SERVICE_PORT_HTTPS/g" \
       -i $NGINX_HOME/nginx.conf
else
   RUNTIME=docker
   if [[ -f $NGINX_HOME/conf.d/includes/k8s-ssl.conf ]] ; then
      rm $NGINX_HOME/conf.d/includes/k8s-ssl.conf
   fi
   sed -e "s/##KUBERNETES_SERVICE_HOST/$SUPERVISOR_IP/g" \
       -e "s/##KUBERNETES_SERVICE_PORT_HTTPS/$SUPERVISOR_PORT/g" \
       -i $NGINX_HOME/nginx.conf
fi

echo "** NGINX configuration **"
echo
cat $NGINX_HOME/nginx.conf

echo "** Proxy configuration **"
echo
cat $NGINX_HOME/proxy.conf

echo "** Additional configurations under conf.d/includes **"
echo
ls -la $NGINX_HOME/conf.d/includes
find $NGINX_HOME/conf.d/includes -type f -exec cat {} \;

echo "** Running NGINX as $RUNTIME mode **"
echo
nginx -g 'daemon off;'